@@ -23,7 +23,8 @@ ergmm <- function(formula,response=NULL,family="Bernoulli",fam.par=NULL,
   ## If the random seed has been specified, save the old seed, to
   ## pick up where it left off. If not, don't.
   if(!is.null(seed)){
-    old.seed<-.Random.seed
+    old.seed<-try(.Random.seed)
+    if(inherits(old.seed,"try-error")) old.seed<-NULL
     .Random.seed<-seed
   }else runif(1) # This is needed to initialize .Random.seed if it isn't already.
   start.seed<-.Random.seed
@@ -125,7 +126,7 @@ ergmm <- function(formula,response=NULL,family="Bernoulli",fam.par=NULL,
     }
   
   v[["starting.seed"]]<-start.seed
-  if(!is.null(seed)) .Random.seed<-old.seed
+  if(!is.null(seed) && !is.null(old.seed)) .Random.seed<-old.seed
   
   v
 }
