@@ -4,8 +4,6 @@
 #include "ergmm_structs.h"
 #define rdunif(a,b) ((int) floor(runif(a,b+1)))
 
-void pairwise_dist(double **A,unsigned int n,unsigned int dim, double **dist);
-void update_dist(double **A,unsigned int i, unsigned int n, unsigned int dim, double **dist);
 double *latentpos_average(double **A, unsigned int n, unsigned int m, double *avA);
 void latentpos_translate(double **A, unsigned int n, unsigned int m, double *by);
 void randeff_translate(double *v, unsigned int n, double by);
